#!/bin/sh
#/usr/bin/connect.sh [session] [open|close|list]
#
# This is a script to make the dial syntax more like that of connect.
# (See http://www.caesium.fr/freeware/connect/)
#
# Instead of doing
#	dial -c 'wget http://foo.invalid/muh.tar.gz; kill $DIAL_PID'
# you can do
#	connect.sh open && wget http://foo.invalid/muh.tar.gz ; connect.sh close
#
# connect.sh list will show you a list of your currently opened sessions.
#
# The session argument only makes sense when using open or close. It allows us
# to have many different connections open at once. For example, when we dial
# normally we might use "connect.sh open" but in a script we could do
# "connect.sh get-cartoons open" so the script doesn't interfere with the 
# normal connection.
#
# If no arguments are given to connect.sh, we will just run dial.

PIDDIR="$HOME"/.dial
if [ ! -n "$1" ]; then
	exec dial
fi
	
if [ -n "$2" ]; then
	SESSION="$1"
	COMMAND="$2"
else
	if [ "$1" = "list" ]; then
		cd "$PIDDIR"
		for i in "`ls`"
			do echo "$i" | sed -n 's/^connect-\(.*\)\.pid$/\1/p'
		done
		exit 0
	fi
        SESSION=default
        COMMAND="$1"
fi
if [ ! -e $PIDDIR ]; then
	echo creating "$PIDDIR"/
	mkdir "$PIDDIR"
fi
PIDFILE="$PIDDIR"/connect-"$SESSION".pid
if [ "$COMMAND" = "open" ]; then
        if [ -e "$PIDFILE" ]; then
                echo "$SESSION session is already open or stale lockfile "$PIDFILE""
                exit 1
        fi
        trap "exit 0" SIGUSR1
        dial -c "kill -USR1 $$" 2>&1 > /dev/null &
	DIALPID=$!
	echo $DIALPID > "$PIDFILE"
	wait $DIALPID
	rm -f "$PIDFILE"
	exit 1
elif [ "$COMMAND" = "close" ]; then
	if [ ! -e "$PIDFILE" ]; then
		echo "$SESSION session is not open"
		exit 1
	fi
        kill -USR1 `cat "$PIDFILE"`
	rm -f "$PIDFILE"
        exit 0
elif [ "$COMMAND" = "list" ]; then
	echo "session argument is not allowed with list"
	exit 1
fi
echo "usage: $0 [session] open|close|list"
exit 1
